@@ -89,4 +89,10 @@ class ModifyBackupPolicyRequest(RpcRequest):
 		return self.get_query_params().get('PreferredBackupTime')
 
 	def set_PreferredBackupTime(self,PreferredBackupTime):
-		self.add_query_param('PreferredBackupTime',PreferredBackupTime)
\ No newline at end of file
+		self.add_query_param('PreferredBackupTime',PreferredBackupTime)
+
+	def get_BackupFrequency(self):
+		return self.get_query_params().get('BackupFrequency')
+
+	def set_BackupFrequency(self,BackupFrequency):
+		self.add_query_param('BackupFrequency',BackupFrequency)
\ No newline at end of file
